spurious: Spurious package call to avoid note of functions outside R...

View source: R/helper_functions.R

spuriousR Documentation

Spurious package call to avoid note of functions outside R folder

Description

For internal use.

Usage

spurious(x)

Arguments

x

x


wallace documentation built on May 7, 2026, 5:07 p.m.