powered by
This function runs the Wallace application in the user's default web browser.
run_wallace(launch.browser = TRUE, port = getOption("shiny.port"))
Whether or not to launch a new browser window.
The port for the shiny server to listen on. Defaults to a random available port.
Jamie Kass <[email protected]>
Gonzalo E. Pinilla-Buitrago <[email protected]>
if(interactive()) { run_wallace() }
Run the code above in your browser using DataLab